#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Fri May 31 16:44:20 2024

@author: lorenzo piu

UPDATES:
    - updated the cut function
    
    - updated the computation of the HRR in the batch reaction rates
    
    - corrected a bug in the chemical timescale computation (SFR mode)
"""

